SystemOrganization addCategory: #ConfigurationOfDaliotsPlayground!

!MetacelloMCVersion methodsFor: '*ConfigurationOfDaliotsPlayground' stamp: 'HwaJong 12/29/2012 19:03'!
loadPackageFromUser
	| packages usersPackageIndex |
	packages := spec packageNames asSortedCollection.
	usersPackageIndex := UIManager default chooseFrom: packages title: 'package to load'.
	usersPackageIndex > 1 ifTrue: [(packages at: usersPackageIndex) loadRequiredForMetacelloMCVersion: self]
	! !

Object subclass: #ConfigurationOfDaliotsPlayground
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!ConfigurationOfDaliotsPlayground class methodsFor: 'private' stamp: 'hjo 7/3/2011 02:51'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'private' stamp: 'hjo 7/3/2011 02:51'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'hjo 7/3/2011 02:51'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'hjo 7/3/2011 02:51'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'loading' stamp: 'hjo 7/3/2011 02:51'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'hjo 7/3/2011 02:51'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'accessing' stamp: 'hjo 7/3/2011 02:51'!
project

	^self new project! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'HwaJong 9/19/2012 14:34'!
validate 
	(MetacelloToolBox validateConfiguration: ConfigurationOfDaliotsPlayground) explore.! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'hjo 5/12/2012 19:02'!
baseline10: spec 
	<version: '1.0-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'hjo 5/12/2012 19:08'!
baseline11: spec 
	<version: '1.1-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'TestableGraphics'.
		spec package: 'Daliot'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'DefragFAT' with: [spec requires: {'Daliot'. 'Range'}].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'hjo 5/12/2012 19:12'!
baseline12: spec 
	<version: '1.2-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'TestableGraphics'.
		spec package: 'Daliot'.
		spec package: 'MulitQuoAndRem'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'DefragFAT' with: [spec requires: {'Daliot'. 'Range'}].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'hjo 5/12/2012 19:16'!
baseline13: spec 
	<version: '1.3-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'TestableGraphics'.
		spec package: 'Daliot'.
		spec package: 'LazyRabbit'.
		spec package: 'MulitQuoAndRem'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'DefragFAT' with: [spec requires: {'Daliot'. 'Range'}].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'hjo 5/12/2012 19:16'!
baseline14: spec 
	<version: '1.4-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'TestableGraphics'.
		spec package: 'Daliot'.
		spec package: 'LazyRabbit'.
		spec package: 'MulitQuoAndRem'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'hjo 5/12/2012 19:17'!
baseline15: spec 
	<version: '1.5-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'TestableGraphics'.
		spec package: 'Daliot'.
		spec package: 'LazyRabbit'.
		spec package: 'MulitQuoAndRem'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'hjo 5/12/2012 19:17'!
baseline16: spec 
	<version: '1.6-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'LazyRabbit'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MulitQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'hjo 5/12/2012 19:17'!
baseline17: spec 
	<version: '1.7-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'LazyRabbit'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MulitQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'hjo 5/12/2012 19:17'!
baseline18: spec 
	<version: '1.8-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'LazyRabbit'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MulitQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'hjo 5/12/2012 19:17'!
baseline19: spec 
	<version: '1.9-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'LazyRabbit'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MulitQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:10'!
baseline20: spec 
	<version: '2.0-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: 'Daliot'].
		spec package: 'Jihachol' with: [spec requires: 'StatPseudoCollections'].
		spec package: 'Jihachol' with: [spec requires: 'LazyRabbit'].
		spec package: 'Jihachol' with: [spec requires: 'MaxClub'].
		spec package: 'Jihachol' with: [spec requires: 'Graph'].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MulitQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:14'!
baseline21: spec 
	<version: '2.1-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: 'Daliot'].
		spec package: 'Jihachol' with: [spec requires: 'StatPseudoCollections'].
		spec package: 'Jihachol' with: [spec requires: 'LazyRabbit'].
		spec package: 'Jihachol' with: [spec requires: 'MaxClub'].
		spec package: 'Jihachol' with: [spec requires: 'Graph'].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MulitQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:14'!
baseline22: spec 
	<version: '2.2-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MulitQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MulitQuoAndRem'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:14'!
baseline23: spec 
	<version: '2.3-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:14'!
baseline24: spec 
	<version: '2.4-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect'.
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline25: spec 
	<version: '2.5-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect'.
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline26: spec 
	<version: '2.6-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect'.
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline27: spec 
	<version: '2.7-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DrillDownMethodSearch' with: [spec requires: 'Daliot'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect'.
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline28: spec 
	<version: '2.8-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DrillDownMethodSearch' with: [spec requires: 'Daliot'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect'.
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.  
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline29: spec 
	<version: '2.9-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: 'LazyRabbit'].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DrillDownMethodSearch' with: [spec requires: 'Daliot'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect'.
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.  
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline30: spec 
	<version: '3.0-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DrillDownMethodSearch' with: [spec requires: 'Daliot'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect'.
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.  
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline31: spec 
	<version: '3.1-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DrillDownMethodSearch' with: [spec requires: 'Daliot'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect'.
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.  
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline32: spec 
	<version: '3.2-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DrillDownMethodSearch' with: [spec requires: 'Daliot'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect'.
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.  
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline33: spec 
	<version: '3.3-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec package: 'DrillDownMethodSearch' with: [spec requires: 'Daliot'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect'.
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.  
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline34: spec 
	<version: '3.4-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec package: 'DrillDownMethodSearch' with: [spec requires: 'Daliot'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.  
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline35: spec 
	<version: '3.5-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: 'Daliot'].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.  
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline36: spec 
	<version: '3.6-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.  
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'UndoRedo'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:15'!
baseline37: spec 
	<version: '3.7-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'UndoRedo'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCommon'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCommon'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCommon'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:16'!
baseline38: spec 
	<version: '3.8-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: 'Daliot'].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'UndoRedo'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCommon'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCommon'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCommon'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:16'!
baseline39: spec 
	<version: '3.9-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: 'Daliot'].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'UndoRedo'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:16'!
baseline40: spec 
	<version: '4.0-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: 'Daliot'].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'UndoRedo'.
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 01:16'!
baseline41: spec 
	<version: '4.1-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: 'Daliot'].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:42'!
baseline42: spec 
	<version: '4.2-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'Daliot'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: 'Daliot'].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:41'!
baseline43: spec 
	<version: '4.3-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'Daliot'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:42'!
baseline44: spec 
	<version: '4.4-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'Daliot'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:42'!
baseline45: spec 
	<version: '4.5-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'Daliot'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:55'!
baseline46: spec 
	<version: '4.6-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'Daliot'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:56'!
baseline47: spec 
	<version: '4.7-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'Daliot'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:16'!
baseline48: spec 
	<version: '4.8-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'Daliot'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'ObjectDiff'.
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:17'!
baseline49: spec 
	<version: '4.9-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'Daliot'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'ObjectDiff'.
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:15'!
baseline50: spec 
	<version: '5.0-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'Daliot'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'ObjectDiff'.
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:17'!
baseline51: spec 
	<version: '5.1-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'Daliot'].
		spec package: 'BloodType' with: [spec requires: 'Daliot'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot'.
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'Daliot'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'. 'Daliot'}].
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'ObjectDiff'.
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'}].
		spec package: 'Range' with: [spec requires: 'Daliot'].
		spec package: 'Roulette' with: [spec requires: 'Daliot'].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: 'Daliot'].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'Daliot'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'Daliot'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:14'!
baseline52: spec 
	<version: '5.2-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff'.
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:15'!
baseline53: spec 
	<version: '5.3-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff'.
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:16'!
baseline54: spec 
	<version: '5.4-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff'.
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/23/2012 00:06'!
baseline55: spec 
	<version: '5.5-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff'.
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/22/2012 23:58'!
baseline56: spec 
	<version: '5.6-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/22/2012 23:34'!
baseline57: spec 
	<version: '5.7-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'DrillDownMethodSearch'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/22/2012 23:10'!
baseline58: spec 
	<version: '5.8-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/22/2012 22:38'!
baseline59: spec 
	<version: '5.9-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy'.
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/22/2012 21:36'!
baseline60: spec 
	<version: '6.0-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: 'Ani'].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/22/2012 21:20'!
baseline61: spec 
	<version: '6.1-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.	
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/22/2012 21:14'!
baseline62: spec 
	<version: '6.2-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/22/2012 21:10'!
baseline63: spec 
	<version: '6.3-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: 'DaliotsMappers'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/25/2012 23:42'!
baseline64: spec 
	<version: '6.4-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: 'DaliotsMappers'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 12/31/2012 11:19'!
baseline65: spec 
	<version: '6.5-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: 'DaliotsMappers'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 1/3/2013 23:02'!
baseline66: spec 
	<version: '6.6-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: 'MultiQuoAndRem'].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: 'DaliotsMappers'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototyping'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 1/8/2013 20:03'!
baseline67: spec 
	<version: '6.7-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: 'DaliotsMappers'].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototyping'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 1/10/2013 12:13'!
baseline68: spec 
	<version: '6.8-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototyping'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo'.
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: 'Range'].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 1/12/2013 18:42'!
baseline69: spec 
	<version: '6.9-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'DrillDownMethodSearch' with: [spec requires: {'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototyping'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 1/19/2013 14:17'!
baseline70: spec 
	<version: '7.0-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'. 'MultiDimensionalEnumeration'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototyping'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 1/21/2013 11:27'!
baseline71: spec 
	<version: '7.1-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'. 'MultiDimensionalEnumeration'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototyping'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'. 'SortDescriptors'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 1/30/2013 02:00'!
baseline72: spec 
	<version: '7.2-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'. 'MultiDimensionalEnumeration'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'ProgressReporterMorph' with: [spec requires: 'QuickPrototyping'].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototyping'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'. 'SortDescriptors'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 2/16/2013 23:04'!
baseline73: spec 
	<version: '7.3-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'. 'MultiDimensionalEnumeration'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'ProgressReporterMorph' with: [spec requires: 'QuickPrototyping'].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototyping'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'Ranking' with: [spec requires: {'SortDescriptors'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'. 'SortDescriptors'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 3/1/2013 18:52'!
baseline74: spec 
	<version: '7.4-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'CenterString'.
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'. 'MultiDimensionalEnumeration'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'ProgressReporterMorph' with: [spec requires: 'QuickPrototyping'].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototyping'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'Ranking' with: [spec requires: {'SortDescriptors'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'. 'SortDescriptors'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'. 'CenterString'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 3/16/2013 15:57'!
baseline75: spec 
	<version: '7.5-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'CenterString'.
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'. 'MultiDimensionalEnumeration'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'ObjectSheet' with: [spec requires: {'LazyRabbit'. 'WaffleLayout'}].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'ProgressReporterMorph' with: [spec requires: 'QuickPrototyping'].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototyping'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'Ranking' with: [spec requires: {'SortDescriptors'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'. 'SortDescriptors'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'. 'CenterString'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		"spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon']."
		spec group: 'DevPacer' with: {'DevPacerPharo20'. 'DevPacerCommon'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 3/18/2013 08:07'!
baseline76: spec 
	<version: '7.6-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'CenterString'.
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'. 'MultiDimensionalEnumeration'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'ObjectSheet' with: [spec requires: {'LazyRabbit'. 'WaffleLayout'}].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'ProgressReporterMorph' with: [spec requires: 'QuickPrototyping'].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototypingCommon'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'Ranking' with: [spec requires: {'SortDescriptors'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'. 'SortDescriptors'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'. 'CenterString'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec group: 'QuickPrototyping' with: {'QuickPrototypingCommon'. 'QuickPrototypingPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		].
	spec for: #'pharo2.0.x' do: [
		"spec package: 'DevPacerPharo20' with: [spec requires: 'DevPacerCommon']."
		spec group: 'DevPacer' with: {'DevPacerPharo20'. 'DevPacerCommon'}.
		spec group: 'QuickPrototyping' with: {'QuickPrototypingCommon'. 'QuickPrototypingPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 3/20/2013 12:41'!
baseline77: spec 
	<version: '7.7-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'CenterString'.
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'. 'MultiDimensionalEnumeration'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'ObjectSheet' with: [spec requires: {'LazyRabbit'. 'WaffleLayout'}].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'ProgressReporterMorph' with: [spec requires: 'QuickPrototyping'].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototypingCommon'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'Ranking' with: [spec requires: {'SortDescriptors'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Sieve' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'. 'SortDescriptors'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'. 'CenterString'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec group: 'QuickPrototyping' with: {'QuickPrototypingCommon'. 'QuickPrototypingPharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		spec project: 'Seaside30' with: 
			[spec
				repository: 'http://www.squeaksource.com/MetacelloRepository';
				className: 'ConfigurationOfSeaside30';
				versionString: '3.0.7.1'].
		spec package: 'LearnSeaside' with: [spec requires: 'Seaside30'].
		].
	spec for: #'pharo2.0.x' do: [
		spec group: 'DevPacer' with: {'DevPacerPharo20'. 'DevPacerCommon'}.
		spec group: 'QuickPrototyping' with: {'QuickPrototypingCommon'. 'QuickPrototypingPharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 3/26/2013 10:59'!
baseline78: spec 
	<version: '7.8-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'CenterString'.
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'. 'MultiDimensionalEnumeration'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'ObjectSheet' with: [spec requires: {'LazyRabbit'. 'WaffleLayout'}].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'ProgressReporterMorph' with: [spec requires: 'QuickPrototyping'].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototypingCommon'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'Ranking' with: [spec requires: {'SortDescriptors'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'SieveCommon' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: 'NumericalError'].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'. 'SortDescriptors'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'. 'CenterString'}]
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo12'}.
		spec package: 'SourceCodeTourGuidePharo12' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo12'}.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo13'}.
		spec package: 'SourceCodeTourGuidePharo13' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo13'}.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec group: 'QuickPrototyping' with: {'QuickPrototypingCommon'. 'QuickPrototypingPharo14'}.
		spec group: 'Sieve' with: {'SieveCommon'. 'SievePharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		spec project: 'Seaside30' with: 
			[spec
				repository: 'http://www.squeaksource.com/MetacelloRepository';
				className: 'ConfigurationOfSeaside30';
				versionString: '3.0.7.1'].
		spec package: 'LearnSeaside' with: [spec requires: 'Seaside30'].
		].
	spec for: #'pharo2.0.x' do: [
		spec group: 'DevPacer' with: {'DevPacerPharo20'. 'DevPacerCommon'}.
		spec group: 'QuickPrototyping' with: {'QuickPrototypingCommon'. 'QuickPrototypingPharo20'}.
		spec group: 'Sieve' with: {'SieveCommon'. 'SievePharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 4/6/2013 12:20'!
baseline79: spec 
	<version: '7.9-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DaliotsPlayground'.
		spec package: 'All'.  
		spec package: 'Ani' with: [spec requires: {'SortDescriptors'. 'LazyRabbit'. 'Daliot'}].  
		spec package: 'AppleScriptProgrammer' with: [spec requires: 'DependencySorter'].
		spec package: 'ArtificalMouseClick'.
		spec package: 'BlackBoxParser' with: [spec requires: 'HashProof'].
		spec package: 'BinarySearch' with: [spec requires: 'NumericalError'].
		spec package: 'BloodType' with: [spec requires: 'MultiDimensionalEnumeration'].
		spec package: 'CenterString'.
		spec package: 'ClassFilter'.
		spec package: 'ChooseOrEnter'.
		spec package: 'CoolEnumerations'.
		spec package: 'CopyHierarchy' with: [spec requires: 'MoveClass'].
		spec package: 'Croquis' with: [spec requires: 'MoveClass'].
		spec package: 'Daliot' with: [spec requires: 'CoolEnumerations'].
		spec package: 'DaliotsMappers' with: [spec requires: 'Range'].
		spec package: 'DefragFAT' with: [spec requires: 'Range'].
		spec package: 'DependencySorter' with: [spec requires: 'LazyRabbit'].
		spec package: 'DevPacerCommon' with: [spec requires: {'DevHelpersBase'. 'Ani'}].
		spec group: 'DevHelpers' with: {'DevPacer'. 'CopyHierarchy'. 'Sieve'. 'SourceCodeTourGuide'}.
		spec package: 'DevHelpersBase'.
		spec package: 'DiceRoller' with: [spec requires: {'BlackBoxParser'. 'CoolEnumerations'}].
		spec package: 'DijEvolution' with: [spec requires: {'SortDescriptors'}].
		spec package: 'Distinction'.
		spec package: 'DocumentLogic'.
		spec package: 'Graph' with: [spec requires: {'MaxClub'. 'Daliot'}].
		spec package: 'HashProof'.
		spec package: 'InteractiveBisect' with: [spec requires: 'LazyRabbit'].
		spec package: 'ImageFamilyTree' with: [spec requires: 'BinarySearch'].
		spec package: 'J' with: [spec requires: {'MultiQuoAndRem'. 'HashProof'. 'Daliot'}].
		spec package: 'Jihachol' with: [spec requires: {'StatPseudoCollections' . 'LazyRabbit' . 'MaxClub' . 'Graph'. 'MultiDimensionalEnumeration'}].
		spec package: 'LazyRabbit'.
		spec package: 'LearnCanvas'.
		spec package: 'MaxClub'.
		spec package: 'MorphoPhysics' with: [spec requires: 'LazyRabbit'].
		spec package: 'MoveClass'.
		spec package: 'MultiQuoAndRem'.
		spec package: 'MultiDimensionalEnumeration' with: [spec requires: {'MultiQuoAndRem'. 'LazyRabbit'}].
		spec package: 'NumericalError'.
		spec package: 'ObjectDiff' with: [spec requires: 'LazyRabbit'].
		spec package: 'ObjectSheet' with: [spec requires: {'LazyRabbit'. 'WaffleLayout'}].
		spec package: 'PCube' with: [spec requires: 'MaxClub'].
		spec package: 'Plotter' with: [spec requires: {'DaliotsMappers'. 'Daliot'. 'LazyRabbit'}].
		spec package: 'PocketCube' with: [spec requires: {'HashProof'. 'LazyRabbit'. 'WaffleLayout'. 'DijEvolution'}].
		spec package: 'PhileasFogg' with: [spec requires: {'LazyRabbit'. 'SortDescriptors'. 'UndoRedo'}].
		spec package: 'ProgressReporterMorph' with: [spec requires: 'QuickPrototyping'].
		spec package: 'Prolog' with: [spec requires: {'HashProof'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuantumLogic' with: [spec requires: {'HashProof'. 'CoolEnumerations'. 'MultiDimensionalEnumeration'}].
		spec package: 'QuickPrototypingCommon'.
		spec package: 'Range' with: [spec requires: {'SortDescriptors'. 'HashProof'}].
		spec package: 'Ranking' with: [spec requires: {'SortDescriptors'}].
		spec package: 'RemoveClassSafely'.
		spec package: 'Roulette' with: [spec requires: {'SortDescriptors'}].
		spec package: 'SieveCommon' with: [spec requires: {'All'. 'DevHelpersBase'. 'SortDescriptors'. 'Daliot'. 'ClassFilter'. 'TGListModel'. 'LazyRabbit'}].
		spec package: 'SketchupRuby' with: [spec requires: 'DependencySorter'].
		spec package: 'SmalltalkQuiz' with: [spec requires: {'Distinction'}].
		spec package: 'SortDescriptors'.
		spec package: 'SourceCodeTourGuideCommon' with: [spec requires: {'DevHelpersBase'. 'Daliot'. 'TGListModel'. 'ChooseOrEnter'. 'HashProof'. 'DocumentLogic'. 'LazyRabbit'}].
		spec package: 'SourceCodeTourGuideOmniBrowser' with: [spec requires: 'SourceCodeTourGuideCommon'].
		spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideCommon'}.
		spec for: #OB do: [spec group: 'SourceCodeTourGuideCore' with: {'SourceCodeTourGuideOmniBrowser'}].
		spec package: 'StatisticalObjects' with: [spec requires: {'NumericalError'. 'LazyRabbit'. 'Range'}].
		spec package: 'StatPseudoCollections' with: [spec requires: {'MultiQuoAndRem'. 'Daliot'}].
		spec package: 'TaxReport' with: [spec requires: {'ChooseOrEnter'}].
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: [spec requires: {'DependencySorter'. 'HashProof'. 'SortDescriptors'}].
		spec package: 'TestableGraphics'.
		spec package: 'TGListModel'.
		spec package: 'UndoRedo' with: [spec requires: 'LazyRabbit'].
		spec package: 'Unification' with: [spec requires: 'ClassFilter'].
		spec package: 'WaffleLayout' with: [spec requires: {'Range'. 'LazyRabbit'}].
		spec package: 'WoodCutPictures' with: [spec requires: 'TestableGraphics'].
		spec package: 'WorkPlayRatioScheduler' with: [spec requires: {'WaffleLayout'. 'LazyRabbit'. 'CenterString'}]
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: [spec requires: 'DevPacerCommon'].
		spec group: 'DevPacer' with: {'DevPacerCommon'. 'DevPacerPharo14'}.
		spec group: 'QuickPrototyping' with: {'QuickPrototypingCommon'. 'QuickPrototypingPharo14'}.
		spec group: 'Sieve' with: {'SieveCommon'. 'SievePharo14'}.
		spec package: 'SourceCodeTourGuidePharo14' with: [spec requires: 'SourceCodeTourGuideCore'].
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'. 'SourceCodeTourGuidePharo14'}.
		spec project: 'Seaside30' with: 
			[spec
				repository: 'http://www.squeaksource.com/MetacelloRepository';
				className: 'ConfigurationOfSeaside30';
				versionString: '3.0.7.1'].
		spec package: 'LearnSeaside' with: [spec requires: 'Seaside30'].
		].
	spec for: #'pharo2.0.x' do: [
		spec group: 'DevPacer' with: {'DevPacerPharo20'. 'DevPacerCommon'}.
		spec group: 'QuickPrototyping' with: {'QuickPrototypingCommon'. 'QuickPrototypingPharo20'}.
		spec group: 'Sieve' with: {'SieveCommon'. 'SievePharo20'}.
		spec group: 'SourceCodeTourGuide' with: {'SourceCodeTourGuideCore'}.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'script' stamp: 'HwaJong 5/11/2013 12:36'!
className: className perform: selector
	(Smalltalk includesKey: className)
		ifTrue: [ |cls|
			cls := Smalltalk at: className.
			(cls respondsTo: selector)
				ifTrue: [ cls perform: selector ]].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'attributes' stamp: 'hjo 8/2/2012 10:45'!
customProjectAttributes

	Smalltalk at: ##OBCodeBrowser ifPresent: [:ignored | ^#(#OB) ].
    ^#()! !

!ConfigurationOfDaliotsPlayground methodsFor: 'script' stamp: 'HwaJong 5/11/2013 12:36'!
disintegrateDevPacerFromTheSystem
	self className: #PacerBase perform: #disintegratePacersFromTheSystem! !

!ConfigurationOfDaliotsPlayground methodsFor: 'script' stamp: 'HwaJong 5/11/2013 12:36'!
integrateDevPacerToTheSystem
	self className: #PacerBase perform: #integratePacersToTheSystem! !

!ConfigurationOfDaliotsPlayground methodsFor: 'accessing' stamp: 'hjo 8/2/2012 12:40'!
project
    ^ project
        ifNil: [ 
            "Bootstrap Metacello if it is not already loaded"
            self class ensureMetacello.
            project := MetacelloMCProject new projectAttributes: self customProjectAttributes.	"Create the Metacello project"
            (Smalltalk at: #'MetacelloVersionConstructor') on: self project: project.	"Construct the project"
            project loadType: #'linear'.	"change to #atomic if desired"
            project ]! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:12'!
version010: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:12'!
version011: spec 
	<version: '1.1' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Daliot' with: 'Daliot-hjo.84']..! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:13'!
version012: spec 
	<version: '1.2' imports: #('1.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:13'!
version013: spec 
	<version: '1.3' imports: #('1.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:13'!
version014: spec 
	<version: '1.4' imports: #('1.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:13'!
version015: spec 
	<version: '1.5' imports: #('1.5-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:13'!
version016: spec 
	<version: '1.6' imports: #('1.6-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:14'!
version017: spec 
	<version: '1.7' imports: #('1.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.4'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:27'!
version018: spec 
	<version: '1.8' imports: #('1.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.4'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:27'!
version019: spec 
	<version: '1.9' imports: #('1.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.4'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:27'!
version020: spec 
	<version: '2.0' imports: #('2.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.4'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.33'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.

		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:27'!
version021: spec 
	<version: '2.1' imports: #('2.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.4'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.33'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.

		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 11/22/2012 10:27'!
version022: spec 
	<version: '2.2' imports: #('2.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.4'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.33'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.

		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:37'!
version023: spec 
	<version: '2.3' imports: #('2.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.4'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.12'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.33'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MulitQuoAndRem' with:  'MulitQuoAndRem-hjo.8'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.155'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:37'!
version024: spec 
	<version: '2.4' imports: #('2.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.4'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.12'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.33'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.155'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:37'!
version025: spec 
	<version: '2.5' imports: #('2.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.9'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.12'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.33'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.155'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:37'!
version026: spec 
	<version: '2.6' imports: #('2.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.12'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.2'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.12'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.33'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.155'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:37'!
version027: spec 
	<version: '2.7' imports: #('2.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'Daliot' with: 'Daliot-hjo.84'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.12'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.33'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.155'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version028: spec 
	<version: '2.8' imports: #('2.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'Daliot' with: 'Daliot-hjo.86'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.12'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.33'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version029: spec 
	<version: '2.9' imports: #('2.5-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.87'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.12'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version030: spec 
	<version: '3.0' imports: #('2.6-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.87'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.12'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version031: spec 
	<version: '3.1' imports: #('2.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.89'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version032: spec 
	<version: '3.2' imports: #('2.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.89'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.15'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.1'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version033: spec 
	<version: '3.3' imports: #('2.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ani' with: 'Ani-hjo.1'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.89'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.27'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.1'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version034: spec 
	<version: '3.4' imports: #('2.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ani' with: 'Ani-hjo.7'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.89'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.27'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.1'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version035: spec 
	<version: '3.5' imports: #('3.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ani' with: 'Ani-hjo.12'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.91'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.27'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.1'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version036: spec 
	<version: '3.6' imports: #('3.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ani' with: 'Ani-hjo.12'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.91'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.27'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.1'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version037: spec 
	<version: '3.7' imports: #('3.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ani' with: 'Ani-hjo.28'.
		spec package: 'Ameba' with: 'Ameba-hjo.8'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.100'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.27'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.1'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version038: spec 
	<version: '3.8' imports: #('3.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ani' with: 'Ani-hjo.28'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.100'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.27'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.1'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version039: spec 
	<version: '3.9' imports: #('3.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ani' with: 'Ani-hjo.40'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.113'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:38'!
version040: spec 
	<version: '4.0' imports: #('3.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ani' with: 'Ani-hjo.42'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.113'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.1'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: 'DevPacerPharo12-hjo.3'.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: 'DevPacerPharo13-hjo.2'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.4'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version041: spec 
	<version: '4.1' imports: #('3.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ani' with: 'Ani-hjo.42'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.113'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.10'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: 'DevPacerPharo12-hjo.3'.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: 'DevPacerPharo13-hjo.2'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version042: spec 
	<version: '4.2' imports: #('3.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.8'.
		spec package: 'Ani' with: 'Ani-hjo.42'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.114'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.10'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: 'DevPacerPharo12-hjo.3'.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: 'DevPacerPharo13-hjo.2'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version043: spec 
	<version: '4.3' imports: #('3.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.42'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.114'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.10'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: 'DevPacerPharo12-hjo.3'.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: 'DevPacerPharo13-hjo.2'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.6'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version044: spec 
	<version: '4.4' imports: #('3.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.42'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.114'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.10'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: 'DevPacerPharo12-hjo.3'.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: 'DevPacerPharo13-hjo.2'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.7'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version045: spec 
	<version: '4.5' imports: #('3.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.42'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.114'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.11'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: 'DevPacerPharo12-hjo.3'.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: 'DevPacerPharo13-hjo.2'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.7'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version046: spec 
	<version: '4.6' imports: #('3.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.42'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'DevPacerPharo12' with: 'DevPacerPharo12-hjo.3'.
		].
	spec for: #'pharo1.3.x' do: [
		spec package: 'DevPacerPharo13' with: 'DevPacerPharo13-hjo.2'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version047: spec 
	<version: '4.7' imports: #('3.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.42'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.13'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.12'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.1'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.9'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version048: spec 
	<version: '4.8' imports: #('3.5-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.42'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.14'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version049: spec 
	<version: '4.9' imports: #('3.5-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.14'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.15'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.12'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.7'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.25'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.22'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.156'.
		spec package: 'Range' with: 'Range-hjo.6'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.3'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version050: spec 
	<version: '5.0' imports: #('3.6-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.46'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version051: spec 
	<version: '5.1' imports: #('3.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.46'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.2'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version052: spec 
	<version: '5.2' imports: #('3.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.46'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:39'!
version053: spec 
	<version: '5.3' imports: #('3.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.46'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version054: spec 
	<version: '5.4' imports: #('3.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.46'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.7'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version055: spec 
	<version: '5.5' imports: #('3.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.46'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.7'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.1'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version056: spec 
	<version: '5.6' imports: #('4.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.46'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.7'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.1'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version057: spec 
	<version: '5.7' imports: #('4.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.46'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.7'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.1'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version058: spec 
	<version: '5.8' imports: #('4.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.46'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.8'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version059: spec 
	<version: '5.9' imports: #('4.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.115'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.46'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.8'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version060: spec 
	<version: '6.0' imports: #('4.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.49'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.8'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.1'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version061: spec 
	<version: '6.1' imports: #('4.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.51'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.10'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.3'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version062: spec 
	<version: '6.2' imports: #('4.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.53'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.10'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.3'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version063: spec 
	<version: '6.3' imports: #('4.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.54'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.10'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:40'!
version064: spec 
	<version: '6.4' imports: #('4.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.55'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.10'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version065: spec 
	<version: '6.5' imports: #('4.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.56'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.10'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version066: spec 
	<version: '6.6' imports: #('4.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.57'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.10'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version067: spec 
	<version: '6.7' imports: #('4.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.57'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.11'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version068: spec 
	<version: '6.8' imports: #('4.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.57'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.11'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version069: spec 
	<version: '6.9' imports: #('4.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.57'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.12'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version070: spec 
	<version: '7.0' imports: #('4.5-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-hjo.117'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.57'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-hjo.171'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.12'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version071: spec 
	<version: '7.1' imports: #('4.6-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.118'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-hjo.57'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-hjo.12'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version072: spec 
	<version: '7.2' imports: #('4.6-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.118'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.59'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.15'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version073: spec 
	<version: '7.3' imports: #('4.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.118'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.59'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.16'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version074: spec 
	<version: '7.4' imports: #('4.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.118'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.65'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.16'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:41'!
version075: spec 
	<version: '7.5' imports: #('4.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.118'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.1'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.65'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.17'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:42'!
version076: spec 
	<version: '7.6' imports: #('4.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.118'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.10'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.65'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.26'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:42'!
version077: spec 
	<version: '7.7' imports: #('4.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.118'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.65'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.33'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-hjo.3'.
		spec package: 'SourceCodeTourGuidePharo20' with: 'SourceCodeTourGuidePharo20-hjo.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:42'!
version078: spec 
	<version: '7.8' imports: #('5.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.118'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.65'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.33'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:42'!
version079: spec 
	<version: '7.9' imports: #('5.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.120'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.65'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.33'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:43'!
version080: spec 
	<version: '8.0' imports: #('5.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.120'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.65'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-hjo.20'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-hjo.3'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.33'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:43'!
version081: spec 
	<version: '8.1' imports: #('5.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.128'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.65'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-hjo.20'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.33'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:43'!
version082: spec 
	<version: '8.2' imports: #('5.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.65'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-hjo.20'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.33'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:43'!
version083: spec 
	<version: '8.3' imports: #('5.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.65'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-hjo.20'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.33'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version084: spec 
	<version: '8.4' imports: #('5.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.66'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-hjo.20'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.33'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version085: spec 
	<version: '8.5' imports: #('5.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.67'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-hjo.20'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.33'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version086: spec 
	<version: '8.6' imports: #('5.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.67'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-hjo.20'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version087: spec 
	<version: '8.7' imports: #('5.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.77'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-hjo.20'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version088: spec 
	<version: '8.8' imports: #('5.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.77'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.24'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version089: spec 
	<version: '8.9' imports: #('5.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.77'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.25'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version090: spec 
	<version: '9.0' imports: #('5.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.77'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-hjo.7'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-hjo.4'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version091: spec 
	<version: '9.1' imports: #('5.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.78'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.7'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-hjo.8'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version092: spec 
	<version: '9.2' imports: #('5.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.78'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.9'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version093: spec 
	<version: '9.3' imports: #('5.4-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.78'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.12'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version094: spec 
	<version: '9.4' imports: #('5.5-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.83'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:44'!
version095: spec 
	<version: '9.5' imports: #('5.6-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.83'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.36'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:45'!
version096: spec 
	<version: '9.6' imports: #('5.6-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.83'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.55'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:45'!
version097: spec 
	<version: '9.7' imports: #('5.6-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.83'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.56'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:45'!
version098: spec 
	<version: '9.8' imports: #('5.6-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.83'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:45'!
version099: spec 
	<version: '9.9' imports: #('5.6-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.92'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.35'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:45'!
version100: spec 
	<version: '10.0' imports: #('5.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.93'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.36'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:45'!
version101: spec 
	<version: '10.1' imports: #('5.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-hjo.26'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.94'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.173'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.36'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:45'!
version102: spec 
	<version: '10.2' imports: #('5.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.94'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-hjo.5'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.174'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.36'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:45'!
version103: spec 
	<version: '10.3' imports: #('5.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.94'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.6'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.174'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.36'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:45'!
version104: spec 
	<version: '10.4' imports: #('5.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.94'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.36'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:45'!
version105: spec 
	<version: '10.5' imports: #('5.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.96'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.36'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:17'!
version106: spec 
	<version: '10.6' imports: #('5.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.99'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.36'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version107: spec 
	<version: '10.7' imports: #('5.7-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.36'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version108: spec 
	<version: '10.8' imports: #('5.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.3'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.1'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.36'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version109: spec 
	<version: '10.9' imports: #('5.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.37'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.5'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version110: spec 
	<version: '11.0' imports: #('5.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.4'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.37'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version111: spec 
	<version: '11.1' imports: #('5.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.129'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.5'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.37'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version112: spec 
	<version: '11.2' imports: #('5.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.5'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.37'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version113: spec 
	<version: '11.3' imports: #('5.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.5'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-SeungBumKim.38'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-hjo.2'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version114: spec 
	<version: '11.4' imports: #('5.8-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.5'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.49'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version115: spec 
	<version: '11.5' imports: #('5.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.5'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.50'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version116: spec 
	<version: '11.6' imports: #('5.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.5'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.51'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:46'!
version117: spec 
	<version: '11.7' imports: #('5.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.57'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.5'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.52'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:47'!
version118: spec 
	<version: '11.8' imports: #('5.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.5'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.52'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:47'!
version119: spec 
	<version: '11.9' imports: #('5.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.6'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.52'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:47'!
version120: spec 
	<version: '12.0' imports: #('5.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.6'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.53'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:47'!
version121: spec 
	<version: '12.1' imports: #('5.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-hjo.12'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.7'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.53'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.38'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:47'!
version122: spec 
	<version: '12.2' imports: #('5.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.19'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.8'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.7'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-JooyungHan.54'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.42'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:47'!
version123: spec 
	<version: '12.3' imports: #('5.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.19'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.7'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-JooyungHan.54'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.3'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 13:47'!
version124: spec 
	<version: '12.4' imports: #('5.9-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-hjo.9'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.19'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.7'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.55'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:13'!
version125: spec 
	<version: '12.5' imports: #('6.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.12'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.11'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.131'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.19'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.7'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.55'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:13'!
version126: spec 
	<version: '12.6' imports: #('6.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.12'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.13'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.132'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.19'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.7'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.7'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.55'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:13'!
version127: spec 
	<version: '12.7' imports: #('6.0-baseline') >
	"7 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.12'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.14'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.132'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.19'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.8'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.55'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.6'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:13'!
version128: spec 
	<version: '12.8' imports: #('6.0-baseline') >
	" 8 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.12'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.132'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.19'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.8'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.56'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:13'!
version129: spec 
	<version: '12.9' imports: #('6.1-baseline') >
	"11 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.13'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.132'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.20'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.60'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version130: spec 
	<version: '13.0' imports: #('6.1-baseline') >
	"12 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.132'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.20'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.60'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-hjo.1'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version131: spec 
	<version: '13.1' imports: #('6.2-baseline') >
	" 17 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.134'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-hjo.3'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.20'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-hjo.7'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.60'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version132: spec 
	<version: '13.2' imports: #('6.3-baseline') >
	" 21 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.134'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.20'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.60'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version133: spec 
	<version: '13.3' imports: #('6.3-baseline') >
	" 24 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.134'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.20'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-hjo.2'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.61'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version134: spec 
	<version: '13.4' imports: #('6.4-baseline') >
	" 25 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.134'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.20'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.58'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.61'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version135: spec 
	<version: '13.5' imports: #('6.4-baseline') >
	" 26 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.135'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.20'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.59'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version136: spec 
	<version: '13.6' imports: #('6.4-baseline') >
	" 27 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.135'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.20'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version137: spec 
	<version: '13.7' imports: #('6.4-baseline') >
	" 28 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.135'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-hjo.12'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version138: spec 
	<version: '13.8' imports: #('6.4-baseline') >
	" 29 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.135'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.13'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version139: spec 
	<version: '13.9' imports: #('6.5-baseline') >
	" 31 December 2012"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.135'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.13'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.8'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:14'!
version140: spec 
	<version: '14.0' imports: #('6.5-baseline') >
	" 2 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.13'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.8'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version141: spec 
	<version: '14.1' imports: #('6.6-baseline') >
	" 3 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-hjo.12'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.1'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.7'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.13'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.8'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version142: spec 
	<version: '14.2' imports: #('6.6-baseline') >
	" 5 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-hjo.44'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.9'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.13'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.8'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version143: spec 
	<version: '14.3' imports: #('6.7-baseline') >
	" 8 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.10'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.8'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.4'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.13'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.8'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version144: spec 
	<version: '14.4' imports: #('6.8-baseline') >
	" 10 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-hjo.28'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.10'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.18'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.4'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-hjo.1'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.13'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.8'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version145: spec 
	<version: '14.5' imports: #('6.9-baseline') >
	" 12 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.29'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.11'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.4'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.14'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version146: spec 
	<version: '14.6' imports: #('6.9-baseline') >
	" 14 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.29'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.11'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.6'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.14'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version147: spec 
	<version: '14.7' imports: #('6.9-baseline') >
	" 15 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.29'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.11'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.6'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.62'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.4'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.16'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version148: spec 
	<version: '14.8' imports: #('6.9-baseline') >
	" 16 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-hjo.15'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.29'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.11'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.7'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.16'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version149: spec 
	<version: '14.9' imports: #('6.9-baseline') >
	" 17 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.29'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.11'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.7'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version150: spec 
	<version: '15.0' imports: #('6.9-baseline') >
	" 18 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.136'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DrillDownMethodSearch' with: 'DrillDownMethodSearch-HwaJong.103'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-hjo.27'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-hjo.34'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.29'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-hjo.32'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.11'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.7'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version151: spec 
	<version: '15.1' imports: #('7.0-baseline') >
	" 19 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.137'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.29'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.7'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-hjo.1'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version152: spec 
	<version: '15.2' imports: #('7.1-baseline') >
	" 21 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.137'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.29'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.7'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:15'!
version153: spec 
	<version: '15.3' imports: #('7.1-baseline') >
	" 21 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.30'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.36'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.8'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version154: spec 
	<version: '15.4' imports: #('7.1-baseline') >
	" 22 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.30'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.8'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.8'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version155: spec 
	<version: '15.5' imports: #('7.1-baseline') >
	" 23 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.30'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.8'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.9'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.11'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version156: spec 
	<version: '15.6' imports: #('7.2-baseline') >
	" 30 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.2'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.1'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.30'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.8'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.9'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version157: spec 
	<version: '15.7' imports: #('7.2-baseline') >
	" 30 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.1'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.30'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.9'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.9'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.9'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version158: spec 
	<version: '15.8' imports: #('7.2-baseline') >
	" 31 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.1'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.30'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.9'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.10'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version159: spec 
	<version: '15.9' imports: #('7.2-baseline') >
	" 31 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.7'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.1'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.30'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.10'.
		spec package: 'Range' with: 'Range-HwaJong.10'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.10'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version160: spec 
	<version: '16.0' imports: #('7.2-baseline') >
	" 31 January 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.1'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.30'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.11'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.10'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version161: spec 
	<version: '16.1' imports: #('7.2-baseline') >
	" 5 February 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.11'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.10'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version162: spec 
	<version: '16.2' imports: #('7.2-baseline') >
	" 6 February 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.12'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.11'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version163: spec 
	<version: '16.3' imports: #('7.2-baseline') >
	" 14 February 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.13'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-hjo.6'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.11'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version164: spec 
	<version: '16.4' imports: #('7.3-baseline') >
	" 16 February 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.13'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.11'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version165: spec 
	<version: '16.5' imports: #('7.3-baseline') >
	" 23 February 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.4'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.13'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.11'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:16'!
version166: spec 
	<version: '16.6' imports: #('7.3-baseline') >
	" 25 February 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.6'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.13'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.11'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:17'!
version167: spec 
	<version: '16.7' imports: #('7.3-baseline') >
	" 1 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.1'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.6'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.14'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.12'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.12'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:17'!
version168: spec 
	<version: '16.8' imports: #('7.4-baseline') >
	" 1 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.6'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.14'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.11'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.63'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.12'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:17'!
version169: spec 
	<version: '16.9' imports: #('7.4-baseline') >
	" 1 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.6'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.14'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.1'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.12'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:17'!
version170: spec 
	<version: '17.0' imports: #('7.4-baseline') >
	" 2 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.6'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.14'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.12'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:17'!
version171: spec 
	<version: '17.1' imports: #('7.5-baseline') >
	" 5 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.6'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.62'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.14'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.12'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:17'!
version172: spec 
	<version: '17.2' imports: #('7.5-baseline') >
	" 5 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.6'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.14'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.12'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:17'!
version173: spec 
	<version: '17.3' imports: #('7.5-baseline') >
	" 6 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.15'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.14'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.12'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:17'!
version174: spec 
	<version: '17.4' imports: #('7.5-baseline') >
	" 6 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.14'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.12'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/9/2013 14:17'!
version175: spec 
	<version: '17.5' imports: #('7.5-baseline') >
	" 7 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.1'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.15'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.12'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/14/2013 12:42'!
version176: spec 
	<version: '17.6' imports: #('7.5-baseline') >
	" 14 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.2'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.16'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.12'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/14/2013 17:55'!
version177: spec 
	<version: '17.7' imports: #('7.5-baseline') >
	" 14 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.3'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.16'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.12'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/14/2013 19:39'!
version178: spec 
	<version: '17.8' imports: #('7.5-baseline') >
	" 14 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.4'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.16'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.12'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/14/2013 23:23'!
version179: spec 
	<version: '17.9' imports: #('7.5-baseline') >
	" 14 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.21'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.4'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.16'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.13'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-hjo.8'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/16/2013 18:31'!
version180: spec 
	<version: '18.0' imports: #('7.5-baseline') >
	" 14 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.4'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototyping' with: 'QuickPrototyping-HwaJong.16'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.13'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/6/2013 12:17'!
version181: spec 
	<version: '18.1' imports: #('7.6-baseline') >
	" 18 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.4'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.13'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/6/2013 12:17'!
version182: spec 
	<version: '18.2' imports: #('7.7-baseline') >
	" 20 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.4'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.13'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/6/2013 12:17'!
version183: spec 
	<version: '18.3' imports: #('7.7-baseline') >
	" 22 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.4'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'Sieve' with: 'Sieve-HwaJong.14'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/6/2013 12:22'!
version184: spec 
	<version: '18.4' imports: #('7.8-baseline') >
	" 26 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.4'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.1'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-hjo.2'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/6/2013 12:22'!
version185: spec 
	<version: '18.5' imports: #('7.9-baseline') >
	" 26 March 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.4'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.1'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/6/2013 12:22'!
version186: spec 
	<version: '18.6' imports: #('7.9-baseline') >
	" 3 April 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.1'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.13'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/6/2013 12:22'!
version187: spec 
	<version: '18.7' imports: #('7.9-baseline') >
	" 6 April 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.1'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.1'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.14'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/20/2013 09:36'!
version188: spec 
	<version: '18.8' imports: #('7.9-baseline') >
	" 20 April 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.1'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/20/2013 12:30'!
version189: spec 
	<version: '18.9' imports: #('7.9-baseline') >
	" 20 April 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.31'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/20/2013 13:31'!
version190: spec 
	<version: '19.0' imports: #('7.9-baseline') >
	" 20 April 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.64'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/20/2013 16:57'!
version191: spec 
	<version: '19.1' imports: #('7.9-baseline') >
	" 20 April 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.68'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/20/2013 17:55'!
version192: spec 
	<version: '19.2' imports: #('7.9-baseline') >
	" 20 April 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.69'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.17'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/25/2013 00:16'!
version193: spec 
	<version: '19.3' imports: #('7.9-baseline') >
	" 25 April 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.69'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.4'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.18'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 4/28/2013 17:05'!
version194: spec 
	<version: '19.4' imports: #('7.9-baseline') >
	" 28 April 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.8'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.69'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.5'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.18'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 5/1/2013 22:16'!
version195: spec 
	<version: '19.5' imports: #('7.9-baseline') >
	" 28 April 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.25'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.9'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.69'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.5'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.18'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.10'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 5/10/2013 16:35'!
version196: spec 
	<version: '19.6' imports: #('7.9-baseline') >
	" 10 May 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.49'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.9'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.69'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.5'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.18'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.12'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 5/10/2013 18:20'!
version197: spec 
	<version: '19.7' imports: #('7.9-baseline') >
	" 10 May 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.50'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.9'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.69'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.5'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.18'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.12'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 5/11/2013 09:34'!
version198: spec 
	<version: '19.8' imports: #('7.9-baseline') >
	" 11 May 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.53'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.9'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.69'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.5'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.18'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.13'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 5/11/2013 11:09'!
version199: spec 
	<version: '19.9' imports: #('7.9-baseline') >
	" 11 May 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' with: 'DevPacerCommon-HwaJong.54'.
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.9'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.69'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.5'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.18'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 'DevPacerPharo14-HwaJong.14'.
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 5/11/2013 12:43'!
version200: spec 
	<version: '20.0' imports: #('7.9-baseline') >
	" 11 May 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' 
			with: 
				[spec preLoadDoIt: #disintegrateDevPacerFromTheSystem.
				spec file: 'DevPacerCommon-HwaJong.56'].
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.15'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.9'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.36'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.32'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.5'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.2'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.69'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.5'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.18'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.2.x' do: [
		spec package: 'ToolDad' with: 'ToolDad-hjo.4'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 
			[spec file: 'DevPacerPharo14-HwaJong.15'.
			spec postLoadDoIt: #integrateDevPacerToTheSystem].
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 6/19/2013 23:28'!
version201: spec 
	<version: '20.1' imports: #('7.9-baseline') >
	" 19 June 2013"
	spec for: #common do: [
		spec blessing: #development.
		spec package: 'All' with: 'All-HwaJong.1'.
		spec package: 'Ani' with: 'Ani-HwaJong.45'.
		spec package: 'AppleScriptProgrammer' with: 'AppleScriptProgrammer-hjo.13'.
		spec package: 'ArtificalMouseClick' with: 'ArtificalMouseClick-HwaJong.2'.
		spec package: 'BetterArgumentNameByDebugger' with: 'BetterArgumentNameByDebugger-HwaJong.3'.
		spec package: 'BetterMethodCategory' with: 'BetterMethodCategory-HwaJong.1'.
		spec package: 'BinarySearch' with:  'BinarySearch-hjo.8'.
		spec package: 'BlackBoxParser' with: 'BlackBoxParser-hjo.12'.
		spec package: 'BloodType' with:  'BloodType-hjo.2'.
		spec package: 'CenterString' with: 'CenterString-HwaJong.2'.
		spec package: 'ChooseOrEnter' with: 'ChooseOrEnter-HwaJong.2'.
		spec package: 'ClassFilter' with: 'ClassFilter-HwaJong.4'.
		spec package: 'CoolEnumerations' with: 'CoolEnumerations-HwaJong.1'.
		spec package: 'CopyHierarchy' with:  'CopyHierarchy-HwaJong.14'.
		spec package: 'Croquis' with: 'Croquis-HwaJong.16'.
		spec package: 'Daliot' with: 'Daliot-HwaJong.138'.
		spec package: 'DaliotsMappers' with: 'DaliotsMappers-HwaJong.8'.
		spec package: 'DefragFAT' with: 'DefragFAT-hjo.50'.
		spec package: 'DependencySorter' with: 'DependencySorter-hjo.3'.
		spec package: 'DevHelpersBase' with: 'DevHelpersBase-HwaJong.1'.
		spec package: 'DevPacerCommon' 
			with: 
				[spec preLoadDoIt: #disintegrateDevPacerFromTheSystem.
				spec file: 'DevPacerCommon-HwaJong.56'].
		spec package: 'DiceRoller' with: 'DiceRoller-hjo.3'.
		spec package: 'DijEvolution' with: 'DijEvolution-HwaJong.27'.
		spec package: 'Distinction' with: 'Distinction-HwaJong.2'.
		spec package: 'DoNCollectN' with: 'DoNCollectN-HwaJong.1'.
		spec package: 'DocumentLogic' with: 'DocumentLogic-HwaJong.25'.
		spec package: 'Figures' with: 'Figures-HwaJong.1'.
		spec package: 'Graph' with:  'Graph-hjo.16'.
		spec package: 'Grooming' with:  'Grooming-HwaJong.2'.
		spec package: 'HangmanRescue' with:  'HangmanRescue-hjo.1'.
		spec package: 'HashProof' with: 'HashProof-HwaJong.9'.
		spec package: 'ImageFamilyTree' with: 'ImageFamilyTree-HwaJong.28'.
		spec package: 'ImageFootprint' with: 'ImageFootprint-HwaJong.16'.
		spec package: 'InteractiveBisect' with: 'InteractiveBisect-HwaJong.13'.
		spec package: 'J' with:  'J-HwaJong.3'.
		spec package: 'Jihachol' with:  'Jihachol-HwaJong.37'.
		spec package: 'LazyRabbit' with:  'LazyRabbit-HwaJong.33'.
		spec package: 'LearnCanvas' with:  'LearnCanvas-HwaJong.7'.
		spec package: 'MaxClub' with:  'MaxClub-hjo.8'.
		spec package: 'MorphoPhysics' with:  'MorphoPhysics-HwaJong.33'.
		spec package: 'MoveClass' with: 'MoveClass-HwaJong.1'.
		spec package: 'MultiDimensionalEnumeration' with:  'MultiDimensionalEnumeration-HwaJong.12'.
		spec package: 'MultiQuoAndRem' with:  'MultiQuoAndRem-HwaJong.3'.
		spec package: 'NumericalError' with: 'NumericalError-HwaJong.1'.
		spec package: 'ObjectDiff' with: 'ObjectDiff-HwaJong.63'.
		spec package: 'ObjectSheet' with: 'ObjectSheet-HwaJong.18'.
		spec package: 'PCube' with:  'PCube-HwaJong.12'.
		spec package: 'PhileasFogg' with:  'PhileasFogg-hjo.36'.
		spec package: 'Plotter' with:  'Plotter-HwaJong.9'.
		spec package: 'PocketCube' with:  'PocketCube-HwaJong.175'.
		spec package: 'ProgressReporterMorph' with:  'ProgressReporterMorph-HwaJong.1'.
		spec package: 'Prolog' with:  'Prolog-HwaJong.19'.
		spec package: 'PullUpToSuperclass' with:  'PullUpToSuperclass-HwaJong.8'.
		spec package: 'QuantumLogic' with: 'QuantumLogic-HwaJong.37'.
		spec package: 'QuickPrototypingCommon' with: 'QuickPrototypingCommon-HwaJong.5'.
		spec package: 'Range' with: 'Range-HwaJong.11'.
		spec package: 'Ranking' with: 'Ranking-HwaJong.2'.
		spec package: 'RemoveClassSafely' with: 'RemoveClassSafely-HwaJong.2'.
		spec package: 'Roulette' with:  'Roulette-HwaJong.4'.
		spec package: 'SieveCommon' with: 'SieveCommon-HwaJong.2'.
		spec package: 'SketchupRuby' with: 'SketchupRuby-hjo.3'.
		spec package: 'SmalltalkQuiz' with: 'SmalltalkQuiz-hjo.9'.
		spec package: 'SortDescriptors' with: 'SortDescriptors-HwaJong.7'.
		spec package: 'SourceCodeTourGuideCommon' with: 'SourceCodeTourGuideCommon-HwaJong.69'.
		spec package: 'SourceCodeTourGuideOmniBrowser' with: 'SourceCodeTourGuideOmniBrowser-HwaJong.5'.
		spec package: 'StatPseudoCollections' with: 'StatPseudoCollections-HwaJong.2'.
		spec package: 'StatisticalObjects' with: 'StatisticalObjects-HwaJong.3'.
		spec package: 'TGListModel' with: 'TGListModel-HwaJong.16'.
		spec package: 'TaxReport' with: 'TaxReport-HwaJong.43'.
		spec package: 'TechnologyTreeOptimizationOfTheCivilizationRevolution' with: 'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.5'.
		spec package: 'TestableGraphics' with: 'TestableGraphics-hjo.5'.
		spec package: 'TinyTower' with: 'TinyTower-HwaJong.1'.
		spec package: 'UndoRedo' with: 'UndoRedo-HwaJong.2'.
		spec package: 'Unification' with: 'Unification-HwaJong.11'.
		spec package: 'WaffleLayout' with: 'WaffleLayout-HwaJong.18'.
		spec package: 'WoodCutPictures' with:  'WoodCutPictures-hjo.6'.
		spec package: 'WorkPlayRatioScheduler' with:  'WorkPlayRatioScheduler-HwaJong.13'.
		].
	spec for: #'pharo1.4.x' do: [
		spec package: 'DevPacerPharo14' with: 
			[spec file: 'DevPacerPharo14-HwaJong.15'.
			spec postLoadDoIt: #integrateDevPacerToTheSystem].
		spec package: 'LearnSeaside' with:  'LearnSeaside-HwaJong.4'.
		spec package: 'QuickPrototypingPharo14' with: 'QuickPrototypingPharo14-HwaJong.1'.
		spec package: 'SievePharo14' with: 'SievePharo14-HwaJong.1'.
		spec package: 'SourceCodeTourGuidePharo14' with: 'SourceCodeTourGuidePharo14-hjo.2'.
		spec package: 'ToolDad' with: 'ToolDad-Pharo14-HwaJong.3'.
		].
	spec for: #'pharo2.0.x' do: [
		spec package: 'DevPacerPharo20' with: 'DevPacerPharo20-HwaJong.5'.
		spec package: 'QuickPrototypingPharo20' with: 'QuickPrototypingPharo20-HwaJong.1'.
		spec package: 'SievePharo20' with: 'SievePharo20-HwaJong.1'.
		].! !
